summaryrefslogtreecommitdiffstats
path: root/tests/PySys/misc_features/valid_device_id/run.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/PySys/misc_features/valid_device_id/run.py')
-rw-r--r--tests/PySys/misc_features/valid_device_id/run.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/PySys/misc_features/valid_device_id/run.py b/tests/PySys/misc_features/valid_device_id/run.py
index 5ad67ec8..264ad768 100644
--- a/tests/PySys/misc_features/valid_device_id/run.py
+++ b/tests/PySys/misc_features/valid_device_id/run.py
@@ -9,7 +9,7 @@ When a temporary directory is created to store the certificate and key
When we create a certificate using the valid characters using the sudo tedge
When we upload the certificate onto the c8y cloud
When we connect to the c8y cloud
-Then we check for the output of the tedge connect and find successfull
+Then we check for the output of the tedge connect and find successful
Cleanup the Certificate and Key path and delete the temporary directory
"""
@@ -22,7 +22,7 @@ class ValidateValidDeviceId(TedgeEnvironment):
# disconnect the device from cloud
self.tedge_disconnect_c8y()
- # create a custom certiticate directory for testing purpose
+ # create a custom certificate directory for testing purpose
create_cert_dir = self.startProcess(
command=self.sudo,
arguments=["mkdir", "/tmp/test-device-certs"],
@@ -103,7 +103,7 @@ class ValidateValidDeviceId(TedgeEnvironment):
self.tedge_connect_c8y_test()
def validate(self):
# validate the connection is successfull
self.assertGrep("tedge_connect_c8y.out", "successful", contains=True)
self.assertGrep("tedge_connect_c8y_test.out", "successful", contains=True)
@@ -103,7 +103,7 @@ class ValidateValidDeviceId(TedgeEnvironment):
self.tedge_connect_c8y_test()
def validate(self):
- # validate the connection is successfull
+ # validate the connection is successful
self.assertGrep("tedge_connect_c8y.out", "successful", contains=True)
self.assertGrep("tedge_connect_c8y_test.out", "successful", contains=True)